@@ -1,3 +1,5 @@
+"""Main application module"""
+
 from dependency_injector.wiring import Provide, inject
 
 from ccheck.container import Container
@@ -8,12 +10,13 @@ from ccheck.services.application import ApplicationService
 def main(
     application_service: ApplicationService = Provide[Container.application_service],
 ) -> None:
+    """Application entrypoint"""
     application_service.run()
 
 
 if __name__ == "__main__":
     container = Container()
-    container.init_resources()
+    container.init_resources()  # type: ignore
     container.wire(modules=[__name__])
 
     main()
