@@ -1,9 +1,13 @@
+"""Exercise factory interface module"""
+
 from abc import ABC, abstractmethod
 
 from ccheck.domain.exercise.exercise import Exercise
 
 
 class ExerciseCreator(ABC):
+    """Exercise factory interface"""
+
     @abstractmethod
     def factory_method(self) -> Exercise:
-        pass
+        """Exercise factory method"""
