@@ -1,7 +1,12 @@
+"""FunctionDefinitionExercise factory module"""
+
+from ccheck.domain.exercise.exercise import Exercise
 from ccheck.domain.exercise.exercise_creator import ExerciseCreator
 from ccheck.exercise.function_definition import FunctionDefinitionExercise
 
 
 class FunctionDefinitionExerciseCreator(ExerciseCreator):
-    def factory_method(self) -> FunctionDefinitionExercise:
+    """FunctionDefinitionExercise factory"""
+
+    def factory_method(self) -> Exercise:
         return FunctionDefinitionExercise()
