@@ -1,7 +1,12 @@
+"""IfStatementExercise factory module"""
+
+from ccheck.domain.exercise.exercise import Exercise
 from ccheck.domain.exercise.exercise_creator import ExerciseCreator
 from ccheck.exercise.if_statement import IfStatementExercise
 
 
 class IfStatementExerciseCreator(ExerciseCreator):
-    def factory_method(self) -> IfStatementExercise:
+    """IfStatementExercise factory"""
+
+    def factory_method(self) -> Exercise:
         return IfStatementExercise()
