@@ -1,3 +1,5 @@
+"""Functions aiding manipulating arrays"""
+
 import itertools
 from typing import List, Optional, TypeVar
 
@@ -22,6 +24,8 @@ def check_for_ordered_subarray(array: List[T], subarray: List[T]) -> bool:
                 for sub_index, sub_element in enumerate(subarray):
                     if array[master_index + sub_index] != sub_element:
                         match = False
+                if match is True:
+                    return match
     except IndexError:
         return False
     return match
@@ -33,4 +37,5 @@ def filter_out_none(array: List[Optional[T]]) -> List[T]:
 
 
 def flatten(arrays: List[List[T]]) -> List[T]:
+    """Return flattened array from single-level nested array of arrays"""
     return list(itertools.chain.from_iterable(arrays))
